@@ -118,23 +118,15 @@ void DOMNormalizer::reinitNormalizerMutex()
 //
 static XMLMutex& gNormalizerMutex()
 {
-
     if (!sNormalizerMutex)
     {
-        XMLMutex* tmpMutex = new XMLMutex;
-        if (XMLPlatformUtils::compareAndSwap((void**)&sNormalizerMutex, tmpMutex, 0))
-        {
-            // Someone beat us to it, so let's clean up ours
-            delete tmpMutex;
-        }
-
-        // Now lock it and try to register it
-        XMLMutexLock lock(sNormalizerMutex);
+        XMLMutexLock lock(XMLPlatformUtils::fgAtomicMutex);
 
         // If we got here first, then register it and set the registered flag
         if (!sRegistered)
         {
-			normalizerMutexCleanup.registerCleanup(DOMNormalizer::reinitNormalizerMutex);
+            sNormalizerMutex = new XMLMutex;
+            normalizerMutexCleanup.registerCleanup(DOMNormalizer::reinitNormalizerMutex);
             sRegistered = true;
         }
     }
@@ -143,17 +135,20 @@ static XMLMutex& gNormalizerMutex()
 
 static XMLMsgLoader& gNormalizerMsgLoader()
 {
-    XMLMutexLock lockInit(&gNormalizerMutex());
-
-    // If we haven't loaded our message yet, then do that
     if (!gMsgLoader)
     {
-        gMsgLoader = XMLPlatformUtils::loadMsgSet(XMLUni::fgXMLErrDomain);
-        if (!gMsgLoader)
-            XMLPlatformUtils::panic(PanicHandler::Panic_CantLoadMsgDomain);
+        XMLMutexLock lockInit(&gNormalizerMutex());
 
-        // Register this object to be cleaned up at termination
-        cleanupMsgLoader.registerCleanup(DOMNormalizer::reinitMsgLoader);
+        // If we haven't loaded our message yet, then do that
+        if (!gMsgLoader)
+        {
+            gMsgLoader = XMLPlatformUtils::loadMsgSet(XMLUni::fgXMLErrDomain);
+            if (!gMsgLoader)
+                XMLPlatformUtils::panic(PanicHandler::Panic_CantLoadMsgDomain);
+
+            // Register this object to be cleaned up at termination
+            cleanupMsgLoader.registerCleanup(DOMNormalizer::reinitMsgLoader);
+        }
     }
 
     return *gMsgLoader;
@@ -169,7 +164,7 @@ DOMNormalizer::DOMNormalizer(MemoryManager* const manager)
     , fMemoryManager(manager)
 {
     fNSScope = new (fMemoryManager) InScopeNamespaces(fMemoryManager);
-};
+}
 
 DOMNormalizer::~DOMNormalizer() {
     delete fNSScope;
@@ -336,8 +331,7 @@ void DOMNormalizer::namespaceFixUp(DOMElementImpl *ele) const {
     // hp aCC complains this i is a redefinition of the i on line 283
     for(int j = 0; j < len; j++) {
         DOMAttr *at = (DOMAttr*)attrMap->item(j);
-        const XMLCh *uri = at->getNamespaceURI();
-        const XMLCh *value = at->getNodeValue();
+        const XMLCh *uri = at->getNamespaceURI();        
         const XMLCh* prefix = at->getPrefix();
 
         if(!XMLString::equals(XMLUni::fgXMLNSURIName, uri)) {
@@ -511,7 +505,7 @@ void DOMNormalizer::InScopeNamespaces::Scope::addOrChangeBinding(const XMLCh *pr
         fUriHash = new (manager) RefHashTableOf<XMLCh>(10, (bool) false, manager);
         
         if(fBaseScopeWithBindings) {
-            RefHashTableOfEnumerator<XMLCh> preEnumer(fBaseScopeWithBindings->fPrefixHash);
+            RefHashTableOfEnumerator<XMLCh> preEnumer(fBaseScopeWithBindings->fPrefixHash, false, manager);
             while(preEnumer.hasMoreElements()) {
                 const XMLCh* prefix = (XMLCh*) preEnumer.nextElementKey();
                 const XMLCh* uri  = fBaseScopeWithBindings->fPrefixHash->get((void*)prefix);
@@ -520,7 +514,7 @@ void DOMNormalizer::InScopeNamespaces::Scope::addOrChangeBinding(const XMLCh *pr
                 fPrefixHash->put((void *)prefix, (XMLCh*)uri);
             }
             
-            RefHashTableOfEnumerator<XMLCh> uriEnumer(fBaseScopeWithBindings->fUriHash);
+            RefHashTableOfEnumerator<XMLCh> uriEnumer(fBaseScopeWithBindings->fUriHash, false, manager);
             while(uriEnumer.hasMoreElements()) {
                 const XMLCh* uri = (XMLCh*) uriEnumer.nextElementKey();
                 const XMLCh* prefix  = fBaseScopeWithBindings->fUriHash->get((void*)uri);
