@@ -55,7 +55,7 @@
  */
 
 /*
- * $Id: DOMRangeImpl.cpp,v 1.14 2003/05/18 14:02:03 knoaman Exp $
+ * $Id: DOMRangeImpl.cpp,v 1.17 2004/01/29 11:44:27 cargilld Exp $
  */
 
 #include "DOMRangeImpl.hpp"
@@ -81,29 +81,31 @@ XERCES_CPP_NAMESPACE_BEGIN
 // C'tor and D'tor
 //---------------------
 
-DOMRangeImpl::DOMRangeImpl(DOMDocument* doc)
+DOMRangeImpl::DOMRangeImpl(DOMDocument* doc, MemoryManager* const manager)
 
-    :   fDocument(doc),
-        fStartContainer(doc),
+    :   fStartContainer(doc),     
         fStartOffset(0),
         fEndContainer(doc),
-        fEndOffset(0),
-        fDetached(false),
+        fEndOffset(0),        
         fCollapsed(true),
-        fRemoveChild(0)
+        fDocument(doc),   
+        fDetached(false),
+        fRemoveChild(0),
+        fMemoryManager(manager)
 {
 }
 
 DOMRangeImpl::DOMRangeImpl(const DOMRangeImpl& other)
+:   fStartContainer(other.fStartContainer),
+    fStartOffset(other.fStartOffset),
+    fEndContainer(other.fEndContainer),
+    fEndOffset(other.fEndOffset),
+    fCollapsed(other.fCollapsed),
+    fDocument(other.fDocument),
+    fDetached(other.fDetached),
+    fRemoveChild(other.fRemoveChild),
+    fMemoryManager(other.fMemoryManager)
 {
-    fDocument = other.fDocument;
-    fStartContainer = other.fStartContainer;
-    fStartOffset = other.fStartOffset;
-    fEndContainer = other.fEndContainer;
-    fEndOffset = other.fEndOffset;
-    fDetached = other.fDetached;
-    fCollapsed = other.fCollapsed;
-    fRemoveChild = other.fRemoveChild;
 }
 
 DOMRangeImpl::~DOMRangeImpl()
@@ -597,8 +599,6 @@ void DOMRangeImpl::surroundContents(DOMNode* newParent)
             DOMRangeException::INVALID_NODE_TYPE_ERR, 0);
     }
 
-    DOMNode* root = (DOMNode*) getCommonAncestorContainer();
-
     DOMNode* realStart = fStartContainer;
     DOMNode* realEnd = fEndContainer;
 
@@ -873,18 +873,18 @@ const XMLCh* DOMRangeImpl::toString() const
             XMLCh* tempString;
             XMLCh temp[4000];
             if ((fEndOffset-fStartOffset) >= 3999)
-                tempString = (XMLCh*) XMLPlatformUtils::fgMemoryManager->allocate
+                tempString = (XMLCh*) fMemoryManager->allocate
                 (
                     (fEndOffset - fStartOffset + 1) * sizeof(XMLCh)
                 );//new XMLCh[fEndOffset-fStartOffset+1];
             else
                 tempString = temp;
 
-            XMLString::subString(tempString, fStartContainer->getNodeValue(), fStartOffset, fEndOffset);
+            XMLString::subString(tempString, fStartContainer->getNodeValue(), fStartOffset, fEndOffset, ((DOMDocumentImpl *)fDocument)->getMemoryManager());
             const XMLCh* retString = ((DOMDocumentImpl *)fDocument)->getPooledString(tempString);
 
             if ((fEndOffset-fStartOffset) >= 3999)
-                XMLPlatformUtils::fgMemoryManager->deallocate(tempString);//delete[] tempString;
+                fMemoryManager->deallocate(tempString);//delete[] tempString;
 
             return retString;
         } else {
@@ -894,18 +894,18 @@ const XMLCh* DOMRangeImpl::toString() const
                 XMLCh* tempString;
                 XMLCh temp[4000];
                 if ((length - fStartOffset) >= 3999)
-                    tempString = (XMLCh*) XMLPlatformUtils::fgMemoryManager->allocate
+                    tempString = (XMLCh*) fMemoryManager->allocate
                     (
                         (length - fStartOffset + 1) * sizeof(XMLCh)
                     );//new XMLCh[length - fStartOffset+1];
                 else
                     tempString = temp;
 
-                XMLString::subString(tempString, fStartContainer->getNodeValue(), fStartOffset, length);
+                XMLString::subString(tempString, fStartContainer->getNodeValue(), fStartOffset, length, ((DOMDocumentImpl *)fDocument)->getMemoryManager());
                 retStringBuf.append(tempString);
 
                 if ((length - fStartOffset) >= 3999)
-                    XMLPlatformUtils::fgMemoryManager->deallocate(tempString);//delete[] tempString;
+                    fMemoryManager->deallocate(tempString);//delete[] tempString;
             }
 
             node = nextNode(node, true);
@@ -963,18 +963,18 @@ const XMLCh* DOMRangeImpl::toString() const
             XMLCh* tempString;
             XMLCh temp[4000];
             if (fEndOffset >= 3999)
-                tempString = (XMLCh*) XMLPlatformUtils::fgMemoryManager->allocate
+                tempString = (XMLCh*) fMemoryManager->allocate
                 (
                     (fEndOffset+1) * sizeof(XMLCh)
                 );//new XMLCh[fEndOffset+1];
             else
                 tempString = temp;
 
-            XMLString::subString(tempString, fEndContainer->getNodeValue(), 0, fEndOffset);
+            XMLString::subString(tempString, fEndContainer->getNodeValue(), 0, fEndOffset, ((DOMDocumentImpl *)fDocument)->getMemoryManager());
             retStringBuf.append(tempString);
 
             if (fEndOffset >= 3999)
-                XMLPlatformUtils::fgMemoryManager->deallocate(tempString);//delete[] tempString;
+                fMemoryManager->deallocate(tempString);//delete[] tempString;
         }
     }
     return ((DOMDocumentImpl *)fDocument)->getPooledString(retStringBuf.getRawBuffer());
@@ -1033,9 +1033,10 @@ bool DOMRangeImpl::hasLegalRootContainer(const DOMNode* node) const {
         case DOMNode::ATTRIBUTE_NODE:
         case DOMNode::DOCUMENT_NODE:
         case DOMNode::DOCUMENT_FRAGMENT_NODE:
-        return true;
+            return true;
+        default:
+            return false;
     }
-    return false;
 }
 
 bool DOMRangeImpl::isLegalContainedNode(const DOMNode* node ) const {
@@ -1048,9 +1049,10 @@ bool DOMRangeImpl::isLegalContainedNode(const DOMNode* node ) const {
        case DOMNode::ATTRIBUTE_NODE:
        case DOMNode::ENTITY_NODE:
        case DOMNode::NOTATION_NODE:
-       return false;
-   }
-   return true;
+            return false;
+       default:
+            return true;
+   }   
 }
 
 XMLSize_t DOMRangeImpl::indexOf(const DOMNode* child, const DOMNode* parent) const
@@ -1275,7 +1277,6 @@ DOMDocumentFragment* DOMRangeImpl::traverseSameContainer( int how )
     if ( fStartOffset==fEndOffset )
             return frag;
 
-    DOMNode* current = fStartContainer;
     DOMNode* cloneCurrent = 0;
 
     // Text node needs special case handling
@@ -1293,18 +1294,18 @@ DOMDocumentFragment* DOMRangeImpl::traverseSameContainer( int how )
             XMLCh* tempString;
             XMLCh temp[4000];
             if (fEndOffset >= 3999)
-                tempString = (XMLCh*) XMLPlatformUtils::fgMemoryManager->allocate
+                tempString = (XMLCh*) fMemoryManager->allocate
                 (
                     (fEndOffset+1) * sizeof(XMLCh)
                 );//new XMLCh[fEndOffset+1];
             else
                 tempString = temp;
 
-            XMLString::subString(tempString, cloneCurrent->getNodeValue(), fStartOffset, fEndOffset);
+            XMLString::subString(tempString, cloneCurrent->getNodeValue(), fStartOffset, fEndOffset, ((DOMDocumentImpl *)fDocument)->getMemoryManager());
             cloneCurrent->setNodeValue(((DOMDocumentImpl *)fDocument)->getPooledString(tempString));
 
             if (fEndOffset >= 3999)
-                XMLPlatformUtils::fgMemoryManager->deallocate(tempString);//delete[] tempString;
+                fMemoryManager->deallocate(tempString);//delete[] tempString;
         }
 
         // set the original text node to its new value
@@ -1700,8 +1701,8 @@ DOMNode* DOMRangeImpl::traversePartiallySelected( DOMNode*n, int how )
  */
 DOMNode* DOMRangeImpl::traverseTextNode( DOMNode*n, bool isLeft, int how )
 {
-    XMLCh* txtValue = XMLString::replicate(n->getNodeValue());
-    ArrayJanitor<XMLCh> janValue(txtValue);
+    XMLCh* txtValue = XMLString::replicate(n->getNodeValue(), fMemoryManager);
+    ArrayJanitor<XMLCh> janValue(txtValue, fMemoryManager);
 
     if ( isLeft )
     {
@@ -1717,7 +1718,7 @@ DOMNode* DOMRangeImpl::traverseTextNode( DOMNode*n, bool isLeft, int how )
             XMLCh oldTemp[4000];
 
             if (offset >= 3999)  {
-                oldNodeValue = (XMLCh*) XMLPlatformUtils::fgMemoryManager->allocate
+                oldNodeValue = (XMLCh*) fMemoryManager->allocate
                 (
                     (offset+1) * sizeof(XMLCh)
                 );//new XMLCh[offset+1];
@@ -1725,13 +1726,13 @@ DOMNode* DOMRangeImpl::traverseTextNode( DOMNode*n, bool isLeft, int how )
             else {
                 oldNodeValue = oldTemp;
             }
-            XMLString::subString(oldNodeValue, txtValue, 0, offset);
+            XMLString::subString(oldNodeValue, txtValue, 0, offset, ((DOMDocumentImpl *)fDocument)->getMemoryManager());
 
             if ( how != CLONE_CONTENTS )
                 n->setNodeValue( ((DOMDocumentImpl *)fDocument)->getPooledString(oldNodeValue) );
 
             if (offset>= 3999)
-                XMLPlatformUtils::fgMemoryManager->deallocate(oldNodeValue);//delete[] oldNodeValue;
+                fMemoryManager->deallocate(oldNodeValue);//delete[] oldNodeValue;
         }
 
         if ( how==DELETE_CONTENTS )
@@ -1747,7 +1748,7 @@ DOMNode* DOMRangeImpl::traverseTextNode( DOMNode*n, bool isLeft, int how )
             XMLCh newTemp[4000];
 
             if (offset >= 3999)  {
-                newNodeValue = (XMLCh*) XMLPlatformUtils::fgMemoryManager->allocate
+                newNodeValue = (XMLCh*) fMemoryManager->allocate
                 (
                     (offset+1) * sizeof(XMLCh)
                 );//new XMLCh[offset+1];
@@ -1755,11 +1756,11 @@ DOMNode* DOMRangeImpl::traverseTextNode( DOMNode*n, bool isLeft, int how )
             else {
                 newNodeValue = newTemp;
             }
-            XMLString::subString(newNodeValue, txtValue, offset, startLen);
+            XMLString::subString(newNodeValue, txtValue, offset, startLen, ((DOMDocumentImpl *)fDocument)->getMemoryManager());
             newNode->setNodeValue( ((DOMDocumentImpl *)fDocument)->getPooledString(newNodeValue) );
 
             if (offset>= 3999)
-                XMLPlatformUtils::fgMemoryManager->deallocate(newNodeValue);//delete[] newNodeValue;
+                fMemoryManager->deallocate(newNodeValue);//delete[] newNodeValue;
 
         }
         return newNode;
@@ -1778,7 +1779,7 @@ DOMNode* DOMRangeImpl::traverseTextNode( DOMNode*n, bool isLeft, int how )
             XMLCh oldTemp[4000];
 
             if (offset >= 3999)  {
-                oldNodeValue = (XMLCh*) XMLPlatformUtils::fgMemoryManager->allocate
+                oldNodeValue = (XMLCh*) fMemoryManager->allocate
                 (
                     (offset+1) * sizeof(XMLCh)
                 );//new XMLCh[offset+1];
@@ -1786,13 +1787,13 @@ DOMNode* DOMRangeImpl::traverseTextNode( DOMNode*n, bool isLeft, int how )
             else {
                 oldNodeValue = oldTemp;
             }
-            XMLString::subString(oldNodeValue, txtValue, offset, endLen);
+            XMLString::subString(oldNodeValue, txtValue, offset, endLen, ((DOMDocumentImpl *)fDocument)->getMemoryManager());
 
             if ( how != CLONE_CONTENTS )
                 n->setNodeValue( ((DOMDocumentImpl *)fDocument)->getPooledString(oldNodeValue) );
 
             if (offset>= 3999)
-                XMLPlatformUtils::fgMemoryManager->deallocate(oldNodeValue);//delete[] oldNodeValue;
+                fMemoryManager->deallocate(oldNodeValue);//delete[] oldNodeValue;
         }
 
         if ( how==DELETE_CONTENTS )
@@ -1808,7 +1809,7 @@ DOMNode* DOMRangeImpl::traverseTextNode( DOMNode*n, bool isLeft, int how )
             XMLCh newTemp[4000];
 
             if (offset >= 3999)  {
-                newNodeValue = (XMLCh*) XMLPlatformUtils::fgMemoryManager->allocate
+                newNodeValue = (XMLCh*) fMemoryManager->allocate
                 (
                     (offset+1) * sizeof(XMLCh)
                 );//new XMLCh[offset+1];
@@ -1816,11 +1817,11 @@ DOMNode* DOMRangeImpl::traverseTextNode( DOMNode*n, bool isLeft, int how )
             else {
                 newNodeValue = newTemp;
             }
-            XMLString::subString(newNodeValue, txtValue, 0, offset);
+            XMLString::subString(newNodeValue, txtValue, 0, offset, ((DOMDocumentImpl *)fDocument)->getMemoryManager());
             newNode->setNodeValue( ((DOMDocumentImpl *)fDocument)->getPooledString(newNodeValue) );
 
             if (offset>= 3999)
-                XMLPlatformUtils::fgMemoryManager->deallocate(newNodeValue);//delete[] newNodeValue;
+                fMemoryManager->deallocate(newNodeValue);//delete[] newNodeValue;
 
         }
         return newNode;
