@@ -57,6 +57,15 @@
 /*
  *
  * $Log: XObjectComparator.cpp,v $
+ * Revision 1.6  2004/01/29 11:46:30  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.5  2003/12/17 00:18:34  cargilld
+ * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
+ *
+ * Revision 1.4  2003/12/16 18:42:27  knoaman
+ * fMayMatch is no longer a data member of IC_Field
+ *
  * Revision 1.3  2003/11/12 20:29:05  peiyongz
  * removal of fIDRefList
  *
@@ -66,7 +75,7 @@
  * Revision 1.1  2003/10/29 16:14:15  peiyongz
  * XObjectComparator/XTemplateComparator
  *
- * $Id: XObjectComparator.cpp,v 1.3 2003/11/12 20:29:05 peiyongz Exp $
+ * $Id: XObjectComparator.cpp,v 1.6 2004/01/29 11:46:30 cargilld Exp $
  *
  */
 
@@ -94,7 +103,7 @@ void XObjectComparator::dumpContent(XMLGrammarPoolImpl* const gramPool)
                                    
 {
     RefHashTableOf<Grammar>*  gramReg = gramPool->fGrammarRegistry;
-    RefHashTableOfEnumerator<Grammar> eNum(gramReg);
+    RefHashTableOfEnumerator<Grammar> eNum(gramReg, false, gramPool->getMemoryManager());
     int itemNumber = 0;        
     while (eNum.hasMoreElements())
     {
@@ -161,8 +170,8 @@ bool XObjectComparator::isEquivalent(Grammar* const lValue
 
 }
 
-bool XObjectComparator::isBaseEquivalent(Grammar* const lValue
-                                       , Grammar* const rValue)
+bool XObjectComparator::isBaseEquivalent(Grammar* const
+                                       , Grammar* const)
 {
     return true;
 }
@@ -874,7 +883,6 @@ bool XObjectComparator::isEquivalent(IC_Field* const lValue
     IS_EQUIVALENT(lValue, rValue)
 
     return (
-             (lValue->fMayMatch == rValue->fMayMatch)  &&
              isEquivalent(lValue->fXPath
                         , rValue->fXPath)              &&
              isEquivalent(lValue->fIdentityConstraint
@@ -911,18 +919,14 @@ bool XObjectComparator::isEquivalent(IdentityConstraint* const lValue
     switch(lValue->getType())
     {
     case IdentityConstraint::UNIQUE: 
-        return isEquivalent((IC_Unique*)lValue, (IC_Unique*)rValue);
-        break;
+        return isEquivalent((IC_Unique*)lValue, (IC_Unique*)rValue);        
     case IdentityConstraint::KEY:
-        return isEquivalent((IC_Key*)lValue, (IC_Key*)rValue);
-        break;
+        return isEquivalent((IC_Key*)lValue, (IC_Key*)rValue);        
     case IdentityConstraint::KEYREF: 
-        return isEquivalent((IC_KeyRef*)lValue, (IC_KeyRef*)rValue);
-        break;
+        return isEquivalent((IC_KeyRef*)lValue, (IC_KeyRef*)rValue);        
     default: 
         //throw exception here
-        return false;
-        break;
+        return false;        
     }
   
 }
