@@ -1,7 +1,7 @@
 /*
  * The Apache Software License, Version 1.1
  *
- * Copyright (c) 2003 The Apache Software Foundation.  All rights
+ * Copyright (c) 2003-2004 The Apache Software Foundation.  All rights
  * reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -55,8 +55,23 @@
  */
 
 /*
- * $Id: XSerializeEngine.cpp,v 1.9 2003/11/25 20:37:40 jberry Exp $
+ * $Id: XSerializeEngine.cpp,v 1.14 2004/01/29 11:46:30 cargilld Exp $
  * $Log: XSerializeEngine.cpp,v $
+ * Revision 1.14  2004/01/29 11:46:30  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.13  2004/01/15 23:42:32  peiyongz
+ * proper allignment for built-in datatype read/write
+ *
+ * Revision 1.12  2004/01/13 16:34:20  cargilld
+ * Misc memory management changes.
+ *
+ * Revision 1.11  2004/01/12 16:27:41  neilg
+ * remove use of static buffers
+ *
+ * Revision 1.10  2003/12/17 00:18:34  cargilld
+ * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
+ *
  * Revision 1.9  2003/11/25 20:37:40  jberry
  * Cleanup build errors/warnings from CodeWarrior
  *
@@ -110,27 +125,29 @@ static const XSerializeEngine::XSerializedObjectId_t fgTemplateObjTag = 0xFFFFFF
 static const XSerializeEngine::XSerializedObjectId_t fgClassMask      = 0x80000000;  // indicates class tag
 static const XSerializeEngine::XSerializedObjectId_t fgMaxObjectCount = 0x3FFFFFFD;  
 
-static XMLCh value1[16];
-static XMLCh value2[16];
-
 #define TEST_THROW_ARG1(condition, data, err_msg) \
 if (condition) \
 { \
-    XMLString::binToText(data, value1, 16, 10); \
-    ThrowXML1(XSerializationException \
+    XMLCh value1[17]; \
+    XMLString::binToText(data, value1, 16, 10, fMemoryManager); \
+    ThrowXMLwithMemMgr1(XSerializationException \
             , err_msg  \
-            , value1); \
+            , value1 \
+            , fMemoryManager); \
 }
 
 #define TEST_THROW_ARG2(condition, data1, data2, err_msg) \
 if (condition) \
 { \
-    XMLString::binToText(data1, value1, 16, 10); \
-    XMLString::binToText(data2, value2, 16, 10); \
-    ThrowXML2(XSerializationException \
+    XMLCh value1[17]; \
+    XMLCh value2[17]; \
+    XMLString::binToText(data1, value1, 16, 10, fMemoryManager); \
+    XMLString::binToText(data2, value2, 16, 10, fMemoryManager); \
+    ThrowXMLwithMemMgr2(XSerializationException \
             , err_msg  \
             , value1   \
-            , value2); \
+            , value2 \
+            , fMemoryManager); \
 }
 
 // ---------------------------------------------------------------------------
@@ -145,8 +162,8 @@ XSerializeEngine::XSerializeEngine(BinInputStream*         inStream
 ,fOutputStream(0)
 ,fBufSize(bufSize)
 ,fBufStart( (XMLByte*) fMemoryManager->allocate(bufSize))
-,fBufCur(fBufStart)
 ,fBufEnd(0)
+,fBufCur(fBufStart)
 ,fBufLoadMax(fBufStart)
 ,fStorePool(0)
 ,fLoadPool( new (fMemoryManager) ValueVectorOf<void*>(29, fMemoryManager, false))
@@ -168,8 +185,8 @@ XSerializeEngine::XSerializeEngine(BinOutputStream*        outStream
 ,fOutputStream(outStream)
 ,fBufSize(bufSize)
 ,fBufStart((XMLByte*) fMemoryManager->allocate(bufSize))
-,fBufCur(fBufStart)
 ,fBufEnd(fBufStart+bufSize)
+,fBufCur(fBufStart)
 ,fBufLoadMax(0)
 ,fStorePool( new (fMemoryManager) RefHashTableOf<XSerializedObjectId>(29, true, new HashPtr(), fMemoryManager) )
 ,fLoadPool(0)
@@ -435,7 +452,7 @@ bool XSerializeEngine::read(XProtoType*            const    protoType
 	{
         // what follows fgNewClassTag is the prototype object info
         // for the object anticipated, go and verify the info
-        XProtoType::load(*this, protoType->fClassName);
+        XProtoType::load(*this, protoType->fClassName, fMemoryManager);
 
         addLoadPool((void*)protoType);
 	}
@@ -631,8 +648,9 @@ XSerializeEngine& XSerializeEngine::operator<<(char ch)
 
 XSerializeEngine& XSerializeEngine::operator<<(short sh)
 { 
-    checkAndFlushBuffer(sizeof(short));
+    checkAndFlushBuffer(allignAdjust()+sizeof(short));
 
+    allignBufCur();
     *(short*)fBufCur = sh; 
     fBufCur += sizeof(short); 
     return *this; 
@@ -640,18 +658,29 @@ XSerializeEngine& XSerializeEngine::operator<<(short sh)
 
 XSerializeEngine& XSerializeEngine::operator<<(int i)
 { 
-    return XSerializeEngine::operator<<((long)i); 
+    checkAndFlushBuffer(allignAdjust()+sizeof(int));
+
+    allignBufCur();
+    *(int*)fBufCur = i; 
+    fBufCur += sizeof(int); 
+    return *this;     
 }
 
 XSerializeEngine& XSerializeEngine::operator<<(unsigned int ui)
 { 
-    return XSerializeEngine::operator<<((unsigned long)ui); 
+    checkAndFlushBuffer(allignAdjust()+sizeof(unsigned int));
+
+    allignBufCur();
+    *(unsigned int*)fBufCur = ui; 
+    fBufCur += sizeof(unsigned int); 
+    return *this; 
 }
 
 XSerializeEngine& XSerializeEngine::operator<<(long l)
 { 
-    checkAndFlushBuffer(sizeof(long));
+    checkAndFlushBuffer(allignAdjust()+sizeof(long));
 
+    allignBufCur();
     *(long*)fBufCur = l; 
     fBufCur += sizeof(long); 
     return *this; 
@@ -659,8 +688,9 @@ XSerializeEngine& XSerializeEngine::operator<<(long l)
 
 XSerializeEngine& XSerializeEngine::operator<<(unsigned long ul)
 { 
-    checkAndFlushBuffer(sizeof(unsigned long));
+    checkAndFlushBuffer(allignAdjust()+sizeof(unsigned long));
 
+    allignBufCur();
     *(unsigned long*)fBufCur = ul; 
     fBufCur += sizeof(unsigned long); 
     return *this; 
@@ -668,8 +698,9 @@ XSerializeEngine& XSerializeEngine::operator<<(unsigned long ul)
 
 XSerializeEngine& XSerializeEngine::operator<<(float f)
 { 
-    checkAndFlushBuffer(sizeof(float));
+    checkAndFlushBuffer(allignAdjust()+sizeof(float));
 
+    allignBufCur();
     *(float*)fBufCur = *(float*)&f; 
     fBufCur += sizeof(float); 
     return *this;
@@ -677,8 +708,9 @@ XSerializeEngine& XSerializeEngine::operator<<(float f)
 
 XSerializeEngine& XSerializeEngine::operator<<(double d)
 { 
-    checkAndFlushBuffer(sizeof(double));
+    checkAndFlushBuffer(allignAdjust()+sizeof(double));
 
+    allignBufCur();
     *(double*)fBufCur = *(double*)&d; 
     fBufCur += sizeof(double); 
     return *this; 
@@ -687,22 +719,6 @@ XSerializeEngine& XSerializeEngine::operator<<(double d)
 // ---------------------------------------------------------------------------
 //  Extraction
 // ---------------------------------------------------------------------------
-/***
-XSerializeEngine& operator>>(XSerializeEngine& serEng
-                           , XSerializable*& serObj)
-{
-    serObj = serEng.read(0); 
-    return serEng; 
-}
-
-XSerializeEngine& operator>>(XSerializeEngine& serEng
-                           , const XSerializable*& serObj)
-{
-    serObj = serEng.read(0); 
-    return serEng; 
-}
-***/
-
 XSerializeEngine& XSerializeEngine::operator>>(XMLCh& xch)
 { 
     checkAndFillBuffer(sizeof(XMLCh));
@@ -737,8 +753,9 @@ XSerializeEngine& XSerializeEngine::operator>>(char& ch)
 
 XSerializeEngine& XSerializeEngine::operator>>(short& sh)
 { 
-    checkAndFillBuffer(sizeof(short));
+    checkAndFillBuffer(allignAdjust()+sizeof(short));
 
+    allignBufCur();
     sh = *(short*)fBufCur; 
     fBufCur += sizeof(short); 
     return *this; 
@@ -746,18 +763,29 @@ XSerializeEngine& XSerializeEngine::operator>>(short& sh)
 
 XSerializeEngine& XSerializeEngine::operator>>(int& i)
 { 
-    return XSerializeEngine::operator>>((long&)i); 
+    checkAndFillBuffer(allignAdjust()+sizeof(int));
+
+    allignBufCur();
+    i = *(int*)fBufCur; 
+    fBufCur += sizeof(int); 
+    return *this; 
 }
 
 XSerializeEngine& XSerializeEngine::operator>>(unsigned int& ui)
 { 
-    return XSerializeEngine::operator>>((unsigned long&)ui); 
+    checkAndFillBuffer(allignAdjust()+sizeof(unsigned int));
+
+    allignBufCur();
+    ui = *(unsigned int*)fBufCur; 
+    fBufCur += sizeof(unsigned int); 
+    return *this; 
 }
 
 XSerializeEngine& XSerializeEngine::operator>>(long& l)
 { 
-    checkAndFillBuffer(sizeof(long));
+    checkAndFillBuffer(allignAdjust()+sizeof(long));
 
+    allignBufCur();
     l = *(long*)fBufCur; 
     fBufCur += sizeof(long); 
     return *this; 
@@ -765,8 +793,9 @@ XSerializeEngine& XSerializeEngine::operator>>(long& l)
 
 XSerializeEngine& XSerializeEngine::operator>>(unsigned long& ul)
 { 
-    checkAndFillBuffer(sizeof(unsigned long));
+    checkAndFillBuffer(allignAdjust()+sizeof(unsigned long));
 
+    allignBufCur();
     ul = *(unsigned long*)fBufCur; 
     fBufCur += sizeof(unsigned long); 
     return *this; 
@@ -774,8 +803,9 @@ XSerializeEngine& XSerializeEngine::operator>>(unsigned long& ul)
 
 XSerializeEngine& XSerializeEngine::operator>>(float& f)
 { 
-    checkAndFillBuffer(sizeof(float));
+    checkAndFillBuffer(allignAdjust()+sizeof(float));
 
+    allignBufCur();
     *(float*)&f = *(float*)fBufCur; 
     fBufCur += sizeof(float); 
     return *this; 
@@ -783,8 +813,9 @@ XSerializeEngine& XSerializeEngine::operator>>(float& f)
 
 XSerializeEngine& XSerializeEngine::operator>>(double& d)
 { 
-    checkAndFillBuffer(sizeof(double));
+    checkAndFillBuffer(allignAdjust()+sizeof(double));
 
+    allignBufCur();
     *(double*)&d = *(double*)fBufCur; 
     fBufCur += sizeof(double); 
     return *this; 
