@@ -56,6 +56,12 @@
 
 /*
  * $Log: SAXParser.cpp,v $
+ * Revision 1.31  2004/01/29 11:46:32  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.30  2003/12/17 00:18:35  cargilld
+ * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
+ *
  * Revision 1.29  2003/11/21 22:38:50  neilg
  * Enable grammar pools and grammar resolvers to manufacture
  * XSModels.  This also cleans up handling in the
@@ -637,7 +643,7 @@ void SAXParser::setSecurityManager(SecurityManager* const securityManager)
     // since this could impact various components, don't permit it to change
     // during a parse
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     fScanner->setSecurityManager(securityManager);
 }
@@ -698,7 +704,7 @@ void SAXParser::parse(const InputSource& source)
 {
     // Avoid multiple entrance
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     try
     {
@@ -721,7 +727,7 @@ void SAXParser::parse(const XMLCh* const systemId)
 {
     // Avoid multiple entrance
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     try
     {
@@ -744,7 +750,7 @@ void SAXParser::parse(const char* const systemId)
 {
     // Avoid multiple entrance
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     try
     {
@@ -861,7 +867,7 @@ bool SAXParser::parseFirst( const   XMLCh* const    systemId
     //  is in progress.
     //
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     return fScanner->scanFirst(systemId, toFill);
 }
@@ -874,7 +880,7 @@ bool SAXParser::parseFirst( const   char* const     systemId
     //  is in progress.
     //
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     return fScanner->scanFirst(systemId, toFill);
 }
@@ -887,7 +893,7 @@ bool SAXParser::parseFirst( const   InputSource&    source
     //  is in progress.
     //
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     return fScanner->scanFirst(source, toFill);
 }
@@ -1178,9 +1184,9 @@ void SAXParser::startEntityReference(const XMLEntityDecl& entityDecl)
 // ---------------------------------------------------------------------------
 //  SAXParser: Overrides of the DocTypeHandler interface
 // ---------------------------------------------------------------------------
-void SAXParser::attDef( const   DTDElementDecl& elemDecl
-                        , const DTDAttDef&      attDef
-                        , const bool            ignoring)
+void SAXParser::attDef( const   DTDElementDecl&
+                        , const DTDAttDef&
+                        , const bool)
 {
     // Unused by SAX DTDHandler interface at this time
 }
@@ -1192,11 +1198,11 @@ void SAXParser::doctypeComment(const XMLCh* const)
 }
 
 
-void SAXParser::doctypeDecl(const   DTDElementDecl& elemDecl
-                            , const XMLCh* const    publicId
-                            , const XMLCh* const    systemId
-                            , const bool            hasIntSubset
-                            , const bool            hasExtSubset)
+void SAXParser::doctypeDecl(const   DTDElementDecl&
+                            , const XMLCh* const
+                            , const XMLCh* const
+                            , const bool
+                            , const bool)
 {
     // Unused by SAX DTDHandler interface at this time
 }
@@ -1209,8 +1215,8 @@ void SAXParser::doctypePI(  const   XMLCh* const
 }
 
 
-void SAXParser::doctypeWhitespace(  const   XMLCh* const    chars
-                                    , const unsigned int    length)
+void SAXParser::doctypeWhitespace(  const   XMLCh* const
+                                    , const unsigned int)
 {
     // Unused by SAX DTDHandler interface at this time
 }
@@ -1241,7 +1247,7 @@ void SAXParser::endExtSubset()
 
 
 void SAXParser::entityDecl( const   DTDEntityDecl&  entityDecl
-                            , const bool            isPEDecl
+                            , const bool
                             , const bool            isIgnored)
 {
     //
@@ -1322,8 +1328,8 @@ void SAXParser::resetErrors()
 }
 
 
-void SAXParser::error(  const   unsigned int                code
-                        , const XMLCh* const                msgDomain
+void SAXParser::error(  const   unsigned int
+                        , const XMLCh* const
                         , const XMLErrorReporter::ErrTypes  errType
                         , const XMLCh* const                errorText
                         , const XMLCh* const                systemId
@@ -1381,7 +1387,7 @@ void SAXParser::resetEntities()
 InputSource*
 SAXParser::resolveEntity(   const   XMLCh* const    publicId
                             , const XMLCh* const    systemId
-                            , const XMLCh* const    baseURI)
+                            , const XMLCh* const)
 {
     // Just map to the SAX entity resolver handler
     if (fEntityResolver)
@@ -1445,7 +1451,7 @@ Grammar* SAXParser::loadGrammar(const char* const systemId,
 {
     // Avoid multiple entrance
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     Grammar* grammar = 0;
     try
@@ -1473,7 +1479,7 @@ Grammar* SAXParser::loadGrammar(const XMLCh* const systemId,
 {
     // Avoid multiple entrance
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     Grammar* grammar = 0;
     try
@@ -1501,7 +1507,7 @@ Grammar* SAXParser::loadGrammar(const InputSource& source,
 {
     // Avoid multiple entrance
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     Grammar* grammar = 0;
     try
