@@ -1,7 +1,7 @@
 /*
  * The Apache Software License, Version 1.1
  *
- * Copyright (c) 2002 The Apache Software Foundation.  All rights
+ * Copyright (c) 2002-2004 The Apache Software Foundation.  All rights
  * reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -56,6 +56,23 @@
 
 /*
  * $Log: BeOSPlatformUtils.cpp,v $
+ * Revision 1.13  2004/01/13 16:34:21  cargilld
+ * Misc memory management changes.
+ *
+ * Revision 1.12  2004/01/06 17:31:20  neilg
+ * fix static initialization problems, bug 28517; thanks to Reid Spencer
+ *
+ * Revision 1.11  2003/12/24 15:24:14  cargilld
+ * More updates to memory management so that the static memory manager.
+ *
+ * Revision 1.10  2003/12/17 15:16:10  cargilld
+ * Platform update for memory management so that the static memory manager (one
+ * used to call Initialize) is only for static data.
+ *
+ * Revision 1.9  2003/12/17 13:58:02  cargilld
+ * Platform update for memory management so that the static memory manager (one
+ * used to call Initialize) is only for static data.
+ *
  * Revision 1.8  2003/10/01 16:32:39  neilg
  * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
  *
@@ -235,54 +252,57 @@ void XMLPlatformUtils::panic(const PanicHandler::PanicReasons reason)
 //  XMLPlatformUtils: File Methods
 // ---------------------------------------------------------------------------
 
-unsigned int XMLPlatformUtils::curFilePos(FileHandle theFile)
+unsigned int XMLPlatformUtils::curFilePos(FileHandle theFile
+                                          , MemoryManager* const manager)
 {
     int curPos = ftell( (FILE*)theFile);
     if (curPos == -1)
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotGetSize);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetSize, manager);
 
     return (unsigned int)curPos;
 }
 
-void XMLPlatformUtils::closeFile(FileHandle theFile)
+void XMLPlatformUtils::closeFile(FileHandle theFile
+                                 , MemoryManager* const manager)
 {
     if (fclose((FILE*)theFile))
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotCloseFile);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotCloseFile, manager);
 }
 
-unsigned int XMLPlatformUtils::fileSize(FileHandle theFile)
+unsigned int XMLPlatformUtils::fileSize(FileHandle theFile
+                                        , MemoryManager* const manager)
 {
     // Get the current position
     long  int curPos = ftell((FILE*) theFile);
     if (curPos == -1)
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotGetCurPos);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotGetCurPos, manager);
 
     // Seek to the end and save that value for return
      if (fseek((FILE*) theFile, 0, SEEK_END))
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotSeekToEnd);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotSeekToEnd, manager);
 
     long int retVal = ftell((FILE*)theFile);
     if (retVal == -1)
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotSeekToEnd);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotSeekToEnd, manager);
 
     // And put the pointer back
 
     if (fseek( (FILE*)theFile, curPos, SEEK_SET) )
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotSeekToPos);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotSeekToPos, manager);
 
     return (unsigned int)retVal;
 }
 
-FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName)
+FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName
+                                      , MemoryManager* const manager)
 {
-    const char* tmpFileName = XMLString::transcode(fileName, fgMemoryManager);
-    ArrayJanitor<char> janText((char*)tmpFileName, fgMemoryManager);
+    const char* tmpFileName = XMLString::transcode(fileName, manager);
+    ArrayJanitor<char> janText((char*)tmpFileName, manager);
     FileHandle retVal = (FILE*)fopen( tmpFileName , "rb" );
 
     if (retVal == NULL)
@@ -290,7 +310,8 @@ FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName)
     return retVal;
 }
 
-FileHandle XMLPlatformUtils::openFile(const char* const fileName)
+FileHandle XMLPlatformUtils::openFile(const char* const fileName
+                                      , MemoryManager* const manager)
 {
     FileHandle retVal = (FILE*)fopen( fileName , "rb" );
 
@@ -299,34 +320,37 @@ FileHandle XMLPlatformUtils::openFile(const char* const fileName)
     return retVal;
 }
 
-FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName)
+FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName
+                                             , MemoryManager* const manager)
 {
-    const char* tmpFileName = XMLString::transcode(fileName, fgMemoryManager);
-    ArrayJanitor<char> janText((char*)tmpFileName, fgMemoryManager);
+    const char* tmpFileName = XMLString::transcode(fileName, manager);
+    ArrayJanitor<char> janText((char*)tmpFileName, manager);
     return fopen( tmpFileName , "wb" );
 }
 
-FileHandle XMLPlatformUtils::openFileToWrite(const char* const fileName)
+FileHandle XMLPlatformUtils::openFileToWrite(const char* const fileName
+                                             , MemoryManager* const manager)
 {
     return fopen( fileName , "wb" );
 }
 
-FileHandle XMLPlatformUtils::openStdInHandle()
+FileHandle XMLPlatformUtils::openStdInHandle(MemoryManager* const manager)
 {
     return (FileHandle)fdopen(dup(0), "rb");
 }
 
 unsigned int
-XMLPlatformUtils::readFileBuffer( FileHandle          theFile
-                                , const unsigned int  toRead
-                                , XMLByte* const      toFill)
+XMLPlatformUtils::readFileBuffer( FileHandle           theFile
+                                , const unsigned int   toRead
+                                , XMLByte* const       toFill
+                                , MemoryManager* const manager)
 {
     size_t noOfItemsRead = fread((void*) toFill, 1, toRead, (FILE*)theFile);
 
     if(ferror((FILE*)theFile))
     {
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotReadFromFile);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotReadFromFile, manager);
     }
 
     return (unsigned int)noOfItemsRead;
@@ -335,7 +359,8 @@ XMLPlatformUtils::readFileBuffer( FileHandle          theFile
 void
 XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
                                    , long                  toWrite
-                                   , const XMLByte* const  toFlush)
+                                   , const XMLByte* const  toFlush
+                                   , MemoryManager* const  manager)
 {
     if (!theFile        ||
         (toWrite <= 0 ) ||
@@ -351,7 +376,7 @@ XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
 
         if(ferror((FILE*)theFile))
         {
-            ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotWriteToFile);
+            ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotWriteToFile, manager);
         }
 
         if (bytesWritten < toWrite) //incomplete write
@@ -367,12 +392,13 @@ XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
     return;
 }
 
-void XMLPlatformUtils::resetFile(FileHandle theFile)
+void XMLPlatformUtils::resetFile(FileHandle theFile
+                                 , MemoryManager* const manager)
 {
     // Seek to the start of the file
     if (fseek((FILE*)theFile, 0, SEEK_SET))
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotResetFile);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotResetFile, manager);
 }
 
 
@@ -388,8 +414,8 @@ XMLCh* XMLPlatformUtils::getFullPath(const XMLCh* const srcPath,
     //  so we know that its not some pathological freaky path. It comes in
     //  in native format, and goes out as Unicode always
     //
-    char* newSrc = XMLString::transcode(srcPath, fgMemoryManager);
-    ArrayJanitor<char> janText(newSrc, fgMemoryManager);
+    char* newSrc = XMLString::transcode(srcPath, manager);
+    ArrayJanitor<char> janText(newSrc, manager);
 
     // Use a local buffer that is big enough for the largest legal path
     char absPath[PATH_MAX + 1];
@@ -398,12 +424,13 @@ XMLCh* XMLPlatformUtils::getFullPath(const XMLCh* const srcPath,
 
     if (!retPath)
     {
-        ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetBasePathName);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotGetBasePathName, manager);
     }
     return XMLString::transcode(absPath, manager);
 }
 
-bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck)
+bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck
+                                  , MemoryManager* const manager)
 {
     // Check for pathological case of empty path
     if (!toCheck[0])
@@ -423,13 +450,13 @@ bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck)
 
 XMLCh* XMLPlatformUtils::getCurrentDirectory(MemoryManager* const manager)
 {
-    char  dirBuf[PATH_MAX + 1];
+    char  dirBuf[PATH_MAX + 2];
     char  *curDir = getcwd(&dirBuf[0], PATH_MAX + 1);
 
     if (!curDir)
     {
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotGetBasePathName);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotGetBasePathName, manager);
     }
 
     return XMLString::transcode(curDir, manager);
@@ -462,7 +489,7 @@ unsigned long XMLPlatformUtils::getCurrentMillis()
 //  XMLPlatformUtils: Platform init method
 // ---------------------------------------------------------------------------
 
-static XMLMutex atomicOpsMutex;
+static XMLMutex* atomicOpsMutex = 0;
 
 void XMLPlatformUtils::platformInit()
 {
@@ -471,8 +498,12 @@ void XMLPlatformUtils::platformInit()
     // Normally, mutexes are created on first use, but there is a
     // circular dependency between compareAndExchange() and
     // mutex creation that must be broken.
-    if (atomicOpsMutex.fHandle == 0)
-        atomicOpsMutex.fHandle = XMLPlatformUtils::makeMutex();
+    if(!atomicOpsMutex)
+    {
+        atomicOpsMutex = new (fgMemoryManager) XMLMutex();
+        if (atomicOpsMutex->fHandle == 0)
+            atomicOpsMutex->fHandle = XMLPlatformUtils::makeMutex();
+    }
 }
 
 void* XMLPlatformUtils::makeMutex()
@@ -483,8 +514,8 @@ void* XMLPlatformUtils::makeMutex()
     pthread_mutexattr_settype(attr, PTHREAD_MUTEX_RECURSIVE_NP);
     if (pthread_mutex_init(mutex, attr))
     {
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::Mutex_CouldNotCreate);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::Mutex_CouldNotCreate, fgMemoryManager);
     }
     pthread_mutexattr_destroy(attr);
     delete attr;
@@ -498,8 +529,8 @@ void XMLPlatformUtils::closeMutex(void* const mtxHandle)
     {
         if (pthread_mutex_destroy((pthread_mutex_t*) mtxHandle))
         {
-            ThrowXML(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotDestroy);
+            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                     XMLExcepts::Mutex_CouldNotDestroy, fgMemoryManager);
         }
         delete (pthread_mutex_t*) mtxHandle;
     }
@@ -512,8 +543,8 @@ void XMLPlatformUtils::lockMutex(void* const mtxHandle)
     {
         if (pthread_mutex_lock((pthread_mutex_t*) mtxHandle))
         {
-            ThrowXML(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotLock);
+            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                     XMLExcepts::Mutex_CouldNotLock, fgMemoryManager);
         }
     }
 }
@@ -525,8 +556,8 @@ void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
     {
         if (pthread_mutex_unlock((pthread_mutex_t*) mtxHandle))
         {
-            ThrowXML(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotUnlock);
+            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                     XMLExcepts::Mutex_CouldNotUnlock, fgMemoryManager);
         }
     }
 }
@@ -540,7 +571,7 @@ void* XMLPlatformUtils::compareAndSwap(void**            toFill
                                      , const void* const newValue
                                      , const void* const toCompare)
 {
-    XMLMutexLock lockMutex(&atomicOpsMutex);
+    XMLMutexLock lockMutex(atomicOpsMutex);
 
     void *retVal = *toFill;
     if (*toFill == toCompare)
@@ -551,14 +582,14 @@ void* XMLPlatformUtils::compareAndSwap(void**            toFill
 
 int XMLPlatformUtils::atomicIncrement(int &location)
 {
-    XMLMutexLock localLock(&atomicOpsMutex);
+    XMLMutexLock localLock(atomicOpsMutex);
 
     return ++location;
 }
 
 int XMLPlatformUtils::atomicDecrement(int &location)
 {
-    XMLMutexLock localLock(&atomicOpsMutex);
+    XMLMutexLock localLock(atomicOpsMutex);
 
     return --location;
 }
@@ -612,8 +643,10 @@ void XMLPlatformUtils::platformTerm()
 {
 #if !defined(APP_NO_THREADS)
     // delete the mutex we created
-	closeMutex(atomicOpsMutex.fHandle);
-	atomicOpsMutex.fHandle = 0;
+	closeMutex(atomicOpsMutex->fHandle);
+	atomicOpsMutex->fHandle = 0;
+    delete atomicOpsMutex;
+    atomicOpsMutex = 0;
 #endif
 }
 
