@@ -1,7 +1,7 @@
 /*
  * The Apache Software License, Version 1.1
  *
- * Copyright (c) 2002 The Apache Software Foundation.  All rights
+ * Copyright (c) 2002-2004 The Apache Software Foundation.  All rights
  * reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -56,6 +56,15 @@
 
 /*
  * $Log: CygwinTransService.cpp,v $
+ * Revision 1.12  2004/01/19 16:06:56  amassari
+ * WideCharToMultiByte and MultiByteToWideChar return 0 on failure, not -1
+ *
+ * Revision 1.11  2004/01/13 16:34:22  cargilld
+ * Misc memory management changes.
+ *
+ * Revision 1.10  2003/12/24 15:24:15  cargilld
+ * More updates to memory management so that the static memory manager.
+ *
  * Revision 1.9  2003/11/08 23:37:00  neilg
  * fix for bug 24287 by Abe Backus.
  *
@@ -828,19 +837,20 @@ CygwinTranscoder::transcodeFrom(  const XMLByte* const      srcData
         {
             if (toEat == 1)
             {
-                XMLCh tmpBuf[16];
-                XMLString::binToText((unsigned int)(*inPtr), tmpBuf, 16, 16);
-                ThrowXML2
+                XMLCh tmpBuf[17];
+                XMLString::binToText((unsigned int)(*inPtr), tmpBuf, 16, 16, getMemoryManager());
+                ThrowXMLwithMemMgr2
                 (
                     TranscodingException
                     , XMLExcepts::Trans_BadSrcCP
                     , tmpBuf
                     , getEncodingName()
+                    , getMemoryManager()
                 );
             }
             else
             {
-                ThrowXML(TranscodingException, XMLExcepts::Trans_BadSrcSeq);
+                ThrowXMLwithMemMgr(TranscodingException, XMLExcepts::Trans_BadSrcSeq, getMemoryManager());
             }
         }
 
@@ -909,14 +919,15 @@ CygwinTranscoder::transcodeTo(const  XMLCh* const   srcData
         //
         if (usedDef && (options == UnRep_Throw))
         {
-            XMLCh tmpBuf[16];
-            XMLString::binToText((unsigned int)*srcPtr, tmpBuf, 16, 16);
-            ThrowXML2
+            XMLCh tmpBuf[17];
+            XMLString::binToText((unsigned int)*srcPtr, tmpBuf, 16, 16, getMemoryManager());
+            ThrowXMLwithMemMgr2
             (
                 TranscodingException
                 , XMLExcepts::Trans_Unrepresentable
                 , tmpBuf
                 , getEncodingName()
+                , getMemoryManager()
             );
         }
 
@@ -1001,27 +1012,23 @@ CygwinLCPTranscoder::~CygwinLCPTranscoder()
 // ---------------------------------------------------------------------------
 //  CygwinLCPTranscoder: Implementation of the virtual transcoder interface
 // ---------------------------------------------------------------------------
-unsigned int CygwinLCPTranscoder::calcRequiredSize(const char* const srcText)
+unsigned int CygwinLCPTranscoder::calcRequiredSize(const char* const srcText
+                                                   , MemoryManager* const manager)
 {
     if (!srcText)
         return 0;
 
-    const unsigned int retVal = ::MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, srcText, -1, NULL, 0);
-    if (retVal == (unsigned int)-1)
-        return 0;
-    return retVal;
+    return ::MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, srcText, -1, NULL, 0);
 }
 
 
-unsigned int CygwinLCPTranscoder::calcRequiredSize(const XMLCh* const srcText)
+unsigned int CygwinLCPTranscoder::calcRequiredSize(const XMLCh* const srcText
+                                                   , MemoryManager* const manager)
 {
     if (!srcText)
         return 0;
 
-    const unsigned int retVal = ::WideCharToMultiByte(CP_ACP, 0, (LPCWSTR)srcText, -1, NULL, 0, NULL, NULL);
-    if (retVal == (unsigned int)-1)
-        return 0;
-    return retVal;
+    return ::WideCharToMultiByte(CP_ACP, 0, (LPCWSTR)srcText, -1, NULL, 0, NULL, NULL);
 }
 
 
@@ -1035,7 +1042,7 @@ char* CygwinLCPTranscoder::transcode(const XMLCh* const toTranscode)
     {
         // Calc the needed size
         const unsigned int neededLen = ::WideCharToMultiByte(CP_ACP, 0, (LPCWSTR)toTranscode, -1, NULL, 0, NULL, NULL);
-        if (neededLen == (unsigned int)-1)
+        if (neededLen == 0)
             return 0;
 
         // Allocate a buffer of that size plus one for the null and transcode
@@ -1065,7 +1072,7 @@ char* CygwinLCPTranscoder::transcode(const XMLCh* const toTranscode,
     {
         // Calc the needed size
         const unsigned int neededLen = ::WideCharToMultiByte(CP_ACP, 0, (LPCWSTR)toTranscode, -1, NULL, 0, NULL, NULL);
-        if (neededLen == (unsigned int)-1)
+        if (neededLen == 0)
             return 0;
 
         // Allocate a buffer of that size plus one for the null and transcode
@@ -1095,7 +1102,7 @@ XMLCh* CygwinLCPTranscoder::transcode(const char* const toTranscode)
     {
         // Calculate the buffer size required
         const unsigned int neededLen = ::MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, toTranscode, -1, NULL, 0);
-        if (neededLen == (unsigned int)-1)
+        if (neededLen == 0)
             return 0;
 
         // Allocate a buffer of that size plus one for the null and transcode
@@ -1124,7 +1131,7 @@ XMLCh* CygwinLCPTranscoder::transcode(const char* const toTranscode,
     {
         // Calculate the buffer size required
         const unsigned int neededLen = ::MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, toTranscode, -1, NULL, 0);
-        if (neededLen == (unsigned int)-1)
+        if (neededLen == 0)
             return 0;
 
         // Allocate a buffer of that size plus one for the null and transcode
@@ -1145,7 +1152,8 @@ XMLCh* CygwinLCPTranscoder::transcode(const char* const toTranscode,
 
 bool CygwinLCPTranscoder::transcode( const   char* const    toTranscode
                                     ,       XMLCh* const    toFill
-                                    , const unsigned int    maxChars)
+                                    , const unsigned int    maxChars
+                                    , MemoryManager* const  manager)
 {
     // Check for a couple of psycho corner cases
     if (!toTranscode || !maxChars)
@@ -1161,7 +1169,7 @@ bool CygwinLCPTranscoder::transcode( const   char* const    toTranscode
     }
 
     // This one has a fixed size output, so try it and if it fails it fails
-    if ( size_t(-1) == ::MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, toTranscode, -1, (LPWSTR)toFill, maxChars + 1) )
+    if ( 0 == ::MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, toTranscode, -1, (LPWSTR)toFill, maxChars + 1) )
         return false;
     return true;
 }
@@ -1169,7 +1177,8 @@ bool CygwinLCPTranscoder::transcode( const   char* const    toTranscode
 
 bool CygwinLCPTranscoder::transcode( const  XMLCh* const    toTranscode
                                     ,       char* const     toFill
-                                    , const unsigned int    maxBytes)
+                                    , const unsigned int    maxBytes
+                                    , MemoryManager* const  manager)
 {
     // Watch for a couple of pyscho corner cases
     if (!toTranscode || !maxBytes)
@@ -1185,7 +1194,7 @@ bool CygwinLCPTranscoder::transcode( const  XMLCh* const    toTranscode
     }
 
     // This one has a fixed size output, so try it and if it fails it fails
-    if ( size_t(-1) == ::WideCharToMultiByte(CP_ACP, 0, (LPCWSTR)toTranscode, -1, toFill, maxBytes + 1, NULL, NULL) )
+    if ( 0 == ::WideCharToMultiByte(CP_ACP, 0, (LPCWSTR)toTranscode, -1, toFill, maxBytes + 1, NULL, NULL) )
         return false;
 
     // Cap it off just in case
