@@ -55,8 +55,35 @@
  */
 
 /*
- * $Id: XMLAbstractDoubleFloat.cpp,v 1.17 2003/10/15 14:50:01 peiyongz Exp $
+ * $Id: XMLAbstractDoubleFloat.cpp,v 1.26 2004/01/29 11:48:46 cargilld Exp $
  * $Log: XMLAbstractDoubleFloat.cpp,v $
+ * Revision 1.26  2004/01/29 11:48:46  cargilld
+ * Code cleanup changes to get rid of various compiler diagnostic messages.
+ *
+ * Revision 1.25  2004/01/13 19:50:56  peiyongz
+ * remove parseContent()
+ *
+ * Revision 1.24  2004/01/12 16:23:39  neilg
+ * remove use of static buffers
+ *
+ * Revision 1.23  2004/01/03 00:03:18  peiyongz
+ * parseContent
+ *
+ * Revision 1.22  2003/12/23 21:48:14  peiyongz
+ * Absorb exception thrown in getCanonicalRepresentation and return 0
+ *
+ * Revision 1.21  2003/12/20 06:21:34  neilg
+ * fix canonical representation production
+ *
+ * Revision 1.20  2003/12/17 00:18:35  cargilld
+ * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
+ *
+ * Revision 1.19  2003/12/12 04:51:29  peiyongz
+ * trailing zeros for double/float w/o decimal point
+ *
+ * Revision 1.18  2003/12/11 21:38:12  peiyongz
+ * support for Canonical Representation for Datatype
+ *
  * Revision 1.17  2003/10/15 14:50:01  peiyongz
  * Bugzilla#22821: locale-sensitive function used to validate 'double' type, patch
  * from jsweeney@spss.com (Jeff Sweeney)
@@ -123,6 +150,7 @@
 //  Includes
 // ---------------------------------------------------------------------------
 #include <xercesc/util/XMLAbstractDoubleFloat.hpp>
+#include <xercesc/util/XMLBigDecimal.hpp>
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/NumberFormatException.hpp>
 #include <xercesc/util/XMLString.hpp>
@@ -136,7 +164,8 @@ XERCES_CPP_NAMESPACE_BEGIN
 //  local data member
 // ---------------------------------------------------------------------------
 static const int BUF_LEN = 64;
-static XMLCh value1[BUF_LEN+1];
+
+static XMLCh expSign[] = {chLatin_e, chLatin_E, chNull};
 
 // ---------------------------------------------------------------------------
 //  ctor/dtor
@@ -161,7 +190,7 @@ XMLAbstractDoubleFloat::~XMLAbstractDoubleFloat()
 void XMLAbstractDoubleFloat::init(const XMLCh* const strValue)
 {
     if ((!strValue) || (!*strValue))
-        ThrowXML(NumberFormatException, XMLExcepts::XMLNUM_emptyString);
+        ThrowXMLwithMemMgr(NumberFormatException, XMLExcepts::XMLNUM_emptyString, fMemoryManager);
 
     fRawData = XMLString::replicate(strValue, fMemoryManager);   // preserve the raw data form
 
@@ -275,7 +304,8 @@ int XMLAbstractDoubleFloat::getSign() const
 //
 //
 int XMLAbstractDoubleFloat::compareValues(const XMLAbstractDoubleFloat* const lValue
-                                        , const XMLAbstractDoubleFloat* const rValue)
+                                        , const XMLAbstractDoubleFloat* const rValue
+                                        , MemoryManager* const manager)
 {
     //
     // case#1: lValue normal
@@ -329,7 +359,7 @@ int XMLAbstractDoubleFloat::compareValues(const XMLAbstractDoubleFloat* const lV
     if ((lValue->isSpecialValue()) &&
         (!rValue->isSpecialValue())  )
     {
-        return compareSpecial(lValue, rValue);
+        return compareSpecial(lValue, manager);
     }
     //
     // case#4: lValue normal
@@ -337,14 +367,14 @@ int XMLAbstractDoubleFloat::compareValues(const XMLAbstractDoubleFloat* const lV
     //
     else
     {
-        return (-1) * compareSpecial(rValue, lValue);
+        return (-1) * compareSpecial(rValue, manager);
     }
 
     return 0;
 }
 
-int XMLAbstractDoubleFloat::compareSpecial(const XMLAbstractDoubleFloat* const specialValue
-                                         , const XMLAbstractDoubleFloat* const normalValue)
+int XMLAbstractDoubleFloat::compareSpecial(const XMLAbstractDoubleFloat* const specialValue                                         
+                                         , MemoryManager* const manager)
 {
     switch (specialValue->fType)
     {
@@ -357,10 +387,11 @@ int XMLAbstractDoubleFloat::compareSpecial(const XMLAbstractDoubleFloat* const s
         return INDETERMINATE;
 
     default:
-        XMLString::binToText(specialValue->fType, value1, 16, 10);
-        ThrowXML1(NumberFormatException
+        XMLCh value1[BUF_LEN+1];
+        XMLString::binToText(specialValue->fType, value1, 16, 10, manager);
+        ThrowXMLwithMemMgr1(NumberFormatException
                 , XMLExcepts::XMLNUM_DBL_FLT_InvalidType
-                , value1);
+                , value1, manager);
         //internal error
         return 0;
     }
@@ -456,6 +487,165 @@ void XMLAbstractDoubleFloat::normalizeDecimalPoint(char* const toNormal)
     }
 }
 
+/***
+ * E2-40
+ *
+ *   3.2.4 float
+ *   3.2.5 double
+ *
+ * . the exponent must be indicated by "E". 
+ *   if the exponent is zero, it must be indicated by "E0". 
+ *
+ * . For the mantissa, 
+ *      the preceding optional "+" sign is prohibited and 
+ *      the decimal point is required. 
+ *
+ * . For the exponent, 
+ *      the preceding optional "+" sign is prohibited. 
+ *      Leading zeroes are prohibited.
+ *      
+ * . Leading and trailing zeroes are prohibited subject to the following: 
+ *   number representations must be normalized such that 
+ *     . there is a single digit, which is non-zero, to the left of the decimal point and
+ *     . at least a single digit to the right of the decimal point.
+ *     . unless the value being represented is zero. 
+ *       The canonical representation for zero is 0.0E0
+ *
+ ***/     
+XMLCh* XMLAbstractDoubleFloat::getCanonicalRepresentation(const XMLCh*         const rawData
+                                                        ,       MemoryManager* const memMgr)
+{
+    // before anything, let's look for special tokens since that
+    // breaks the calls to parse below.
+    if(XMLString::equals(rawData, XMLUni::fgNegINFString)
+            || XMLString::equals(rawData, XMLUni::fgPosINFString)
+            || XMLString::equals(rawData, XMLUni::fgNaNString))
+    {
+        return XMLString::replicate(rawData, memMgr);
+    }
+
+    try 
+    {
+
+    int    strLen = XMLString::stringLen(rawData);
+    XMLCh* manStr = (XMLCh*) memMgr->allocate((strLen + 1) * sizeof(XMLCh));
+    ArrayJanitor<XMLCh> janManStr(manStr, memMgr);
+    XMLCh* manBuf = (XMLCh*) memMgr->allocate((strLen + 1) * sizeof(XMLCh));
+    ArrayJanitor<XMLCh> janManBuf(manBuf, memMgr);
+
+    XMLCh* expStr = (XMLCh*) memMgr->allocate((strLen + 1) * sizeof(XMLCh));
+    ArrayJanitor<XMLCh> janExp(expStr, memMgr);
+
+    XMLCh* retBuffer = (XMLCh*) memMgr->allocate((strLen + 8) * sizeof(XMLCh));
+    retBuffer[0] = 0;
+
+    int sign, totalDigits, fractDigits;
+    int expValue = 0;
+
+    const XMLCh* ePosition = XMLString::findAny(rawData, expSign);
+
+    /***
+     *  parse mantissa and exp separately
+     ***/
+    if (!ePosition)
+    {
+        XMLBigDecimal::parseDecimal(rawData, manBuf, sign, totalDigits, fractDigits, memMgr);
+        expValue = 0;
+    }
+    else
+    {
+        int    manLen = ePosition - rawData;
+        XMLString::copyNString(manStr, rawData, manLen);
+        *(manStr + manLen) = chNull;
+        XMLBigDecimal::parseDecimal(manStr, manBuf, sign, totalDigits, fractDigits, memMgr);
+
+        int    expLen = strLen - manLen - 1;
+        ePosition++;
+        XMLString::copyNString(expStr, ePosition, expLen);
+        *(expStr + expLen) = chNull;
+        expValue = XMLString::parseInt(expStr); 
+    }
+
+    if ( (sign == 0) || (totalDigits == 0) )
+    {
+        retBuffer[0] = chDigit_0;
+        retBuffer[1] = chPeriod;
+        retBuffer[2] = chDigit_0;
+        retBuffer[3] = chLatin_E;
+        retBuffer[4] = chDigit_0;
+        retBuffer[5] = chNull;
+    }
+    else
+    {
+        XMLCh* retPtr = retBuffer;
+
+        if (sign == -1)
+        {
+            *retPtr++ = chDash;
+        }
+
+        *retPtr++ = manBuf[0];
+        *retPtr++ = chPeriod;
+
+        //XMLBigDecimal::parseDecimal() will eliminate trailing zeros
+        // iff there is a decimal points
+        // eg. 56.7800e0  -> manBuf = 5678, totalDigits = 4, fractDigits = 2
+        // we print it as 5.678e1
+        //
+        // but it wont remove trailing zeros if there is no decimal point.
+        // eg.  567800e0 -> manBuf = 567800, totalDigits = 6, fractDigits = 0
+        // we print it 5.67800e5
+        //
+        // for the latter, we need to print it as 5.678e5 instead
+        //
+        XMLCh* endPtr = manBuf + totalDigits;
+
+        if (fractDigits == 0)
+        {
+            while(*(endPtr - 1) == chDigit_0)
+                endPtr--;
+        }
+
+        int remainLen = endPtr - &(manBuf[1]);
+
+        if (remainLen)
+        {
+            XMLString::copyNString(retPtr, &(manBuf[1]), remainLen);
+            retPtr += remainLen;
+        }
+        else
+        {
+            *retPtr++ = chDigit_0;
+        }
+
+        /***
+         * 
+         *  . adjust expValue
+         *   
+         *  new_fractDigits = totalDigits - 1  
+         *  new_expValue = old_expValue + (new_fractDigits - fractDigits)
+         *
+         ***/
+        expValue += (totalDigits - 1) - fractDigits ;
+        XMLString::binToText(expValue, expStr, strLen, 10, memMgr);
+        *retPtr++  = chLatin_E;
+        *retPtr = chNull;
+
+
+        XMLString::catString(&(retBuffer[0]), expStr);
+
+    }
+
+    return retBuffer;
+
+    } //try
+
+    catch (...)
+    {
+        return 0;
+    }
+}        
+
 /***
  * Support for Serialization/De-serialization
  ***/
