@@ -1,7 +1,7 @@
 /*
  * The Apache Software License, Version 1.1
  *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
+ * Copyright (c) 1999-2004 The Apache Software Foundation.  All rights
  * reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -55,7 +55,7 @@
  */
 
 /*
- * $Id: XMLURL.cpp,v 1.10 2003/10/02 09:33:24 gareth Exp $
+ * $Id: XMLURL.cpp,v 1.14 2004/01/13 16:34:20 cargilld Exp $
  */
 
 
@@ -221,8 +221,8 @@ XMLURL::XMLURL(const XMLCh* const    baseURL
     , fHasInvalidChar(false)
 {
 	try
-	{
-		setURL(baseURL, relativeURL);
+	{	
+        setURL(baseURL, relativeURL);
 	}
     catch(const OutOfMemoryException&)
     {
@@ -424,6 +424,7 @@ XMLURL::XMLURL(const XMLURL& toCopy) :
     catch(...)
     {
         cleanup();
+        throw;
     }
 }
 
@@ -445,14 +446,17 @@ XMLURL& XMLURL::operator=(const XMLURL& toAssign)
     cleanup();
 
     // And copy his stuff
+    fMemoryManager = toAssign.fMemoryManager;
     fFragment = XMLString::replicate(toAssign.fFragment, fMemoryManager);
     fHost = XMLString::replicate(toAssign.fHost, fMemoryManager);
     fPassword = XMLString::replicate(toAssign.fPassword, fMemoryManager);
     fPath = XMLString::replicate(toAssign.fPath, fMemoryManager);
+    fPortNum = toAssign.fPortNum;
     fProtocol = toAssign.fProtocol;
     fQuery = XMLString::replicate(toAssign.fQuery, fMemoryManager);
     fUser = XMLString::replicate(toAssign.fUser, fMemoryManager);
     fURLText = XMLString::replicate(toAssign.fURLText, fMemoryManager);
+    fHasInvalidChar = toAssign.fHasInvalidChar;
 
     return *this;
 }
@@ -495,7 +499,7 @@ const XMLCh* XMLURL::getProtocolName() const
 {
     // Check to see if its ever been set
     if (fProtocol == Unknown)
-        ThrowXML(MalformedURLException, XMLExcepts::URL_NoProtocolPresent);
+        ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_NoProtocolPresent, fMemoryManager);
 
     return gProtoList[fProtocol].prefix;
 }
@@ -533,12 +537,41 @@ void XMLURL::setURL(const XMLCh* const    baseURL
 			if (!conglomerateWithBase(basePart, false))
 			{
 				cleanup();
-				ThrowXML(MalformedURLException, XMLExcepts::URL_RelativeBaseURL);
+				ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_RelativeBaseURL, fMemoryManager);
 			}
 		}
 	}
 }
 
+// this version of setURL doesn't throw a malformedurl exception
+// instead it returns false when it failed (or when it would of
+// thrown a malformedurl exception)
+bool XMLURL::setURL(const XMLCh* const    baseURL
+                  , const XMLCh* const    relativeURL
+                  , XMLURL& xmlURL)
+{
+    cleanup();
+
+    // Parse our URL string
+    if (parse(relativeURL, xmlURL))
+    {
+	    //  If its relative and the base is non-null and non-empty, then
+	    //  parse the base URL string and conglomerate them.
+	    //
+	    if (isRelative() && baseURL && *baseURL)
+	    {		   
+	        XMLURL basePart(fMemoryManager);
+            if (parse(baseURL, basePart)  && conglomerateWithBase(basePart, false))
+            {    
+		        return true;			                    
+		    }
+	    }
+        else
+            return true;
+    }
+    return false;
+}
+
 void XMLURL::setURL(const XMLURL&         baseURL
                   , const XMLCh* const    relativeURL)
 {
@@ -598,7 +631,7 @@ BinInputStream* XMLURL::makeNewStream() const
             // HTTP protocol will be done automatically by the netaccessor
             //
             int end = XMLString::stringLen(realPath);
-            int percentIndex = XMLString::indexOf(realPath, chPercent, 0);
+            int percentIndex = XMLString::indexOf(realPath, chPercent, 0, fMemoryManager);
 
             while (percentIndex != -1) {
 
@@ -609,10 +642,11 @@ BinInputStream* XMLURL::makeNewStream() const
                     XMLCh value1[4];
                     XMLString::moveChars(value1, &(realPath[percentIndex]), 3);
                     value1[3] = chNull;
-                    ThrowXML2(MalformedURLException
+                    ThrowXMLwithMemMgr2(MalformedURLException
                             , XMLExcepts::XMLNUM_URI_Component_Invalid_EscapeSequence
                             , realPath
-                            , value1);
+                            , value1
+                            , fMemoryManager);
                 }
 
                 unsigned int value = (xlatHexDigit(realPath[percentIndex+1]) * 16) + xlatHexDigit(realPath[percentIndex+2]);
@@ -625,7 +659,7 @@ BinInputStream* XMLURL::makeNewStream() const
                 realPath[i] = chNull;
                 end = i;
 
-                percentIndex = XMLString::indexOf(realPath, chPercent, percentIndex);
+                percentIndex = XMLString::indexOf(realPath, chPercent, percentIndex, fMemoryManager);
             }
 
 
@@ -644,7 +678,7 @@ BinInputStream* XMLURL::makeNewStream() const
     //  have to just throw here.
     //
     if (!XMLPlatformUtils::fgNetAccessor)
-        ThrowXML(MalformedURLException, XMLExcepts::URL_UnsupportedProto);
+        ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_UnsupportedProto, fMemoryManager);
 
     // Else ask the net accessor to create the stream
     return XMLPlatformUtils::fgNetAccessor->makeNew(*this);
@@ -735,8 +769,8 @@ void XMLURL::buildFullText()
         {
             *outPtr++ = chColon;
 
-            XMLCh tmpBuf[16];
-            XMLString::binToText(fPortNum, tmpBuf, 16, 10);
+            XMLCh tmpBuf[17];
+            XMLString::binToText(fPortNum, tmpBuf, 16, 10, fMemoryManager);
             XMLString::copyString(outPtr, tmpBuf);
             outPtr += XMLString::stringLen(tmpBuf);
         }
@@ -791,6 +825,7 @@ void XMLURL::cleanup()
 
     fProtocol = Unknown;
     fPortNum = 0;
+    fHasInvalidChar = false;
 }
 
 
@@ -804,7 +839,7 @@ bool XMLURL::conglomerateWithBase(const XMLURL& baseURL, bool useExceptions)
     if (baseURL.isRelative())
     {
         if (useExceptions)
-			ThrowXML(MalformedURLException, XMLExcepts::URL_RelativeBaseURL);
+			ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_RelativeBaseURL, fMemoryManager);
         else
             return false;
     }
@@ -883,7 +918,7 @@ bool XMLURL::conglomerateWithBase(const XMLURL& baseURL, bool useExceptions)
 
     // Its a relative path, so weave them together.
     if (baseURL.fPath) {
-        XMLCh* temp = XMLPlatformUtils::weavePaths(baseURL.fPath, fPath);
+        XMLCh* temp = XMLPlatformUtils::weavePaths(baseURL.fPath, fPath ,fMemoryManager);
         fMemoryManager->deallocate(fPath);//delete [] fPath;
         fPath = temp;
     }
@@ -908,7 +943,7 @@ void XMLURL::parse(const XMLCh* const urlText)
 {
     // Simplify things by checking for the psycho scenarios first
     if (!*urlText)
-        ThrowXML(MalformedURLException, XMLExcepts::URL_NoProtocolPresent);
+        ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_NoProtocolPresent, fMemoryManager);
 
     // Before we start, check if this urlText contains valid uri characters
     if (!XMLUri::isURIString(urlText))
@@ -929,7 +964,7 @@ void XMLURL::parse(const XMLCh* const urlText)
             if ((*(urlText + 2) == chForwardSlash)
             ||  (*(urlText + 2) == chBackSlash))
             {
-                ThrowXML(MalformedURLException, XMLExcepts::URL_NoProtocolPresent);
+                ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_NoProtocolPresent, fMemoryManager);
             }
         }
     }
@@ -954,7 +989,7 @@ void XMLURL::parse(const XMLCh* const urlText)
 
     // Make sure it wasn't all space
     if (!*srcPtr)
-        ThrowXML(MalformedURLException, XMLExcepts::URL_NoProtocolPresent);
+        ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_NoProtocolPresent, fMemoryManager);
 
     //
     //  Ok, the next thing we have to do is to find either a / or : character.
@@ -977,11 +1012,12 @@ void XMLURL::parse(const XMLCh* const urlText)
 
             if (fProtocol == Unknown)
             {
-                ThrowXML1
+                ThrowXMLwithMemMgr1
                 (
                     MalformedURLException
                     , XMLExcepts::URL_UnsupportedProto1
                     , srcPtr
+                    , fMemoryManager
                 );
             }
 
@@ -1021,7 +1057,7 @@ void XMLURL::parse(const XMLCh* const urlText)
                     fMemoryManager->deallocate(fHost);//delete [] fHost;
                     fHost = (XMLCh*) fMemoryManager->allocate
                     (
-                        (ptr1 - srcPtr + 1) * sizeof(XMLCh)
+                        ((ptr1 - srcPtr) + 1) * sizeof(XMLCh)
                     );//new XMLCh[(ptr1 - srcPtr) + 1];
                     ptr2 = fHost;
                     while (srcPtr < ptr1)
@@ -1046,10 +1082,11 @@ void XMLURL::parse(const XMLCh* const urlText)
         // we didn't get them, so throw an exception
         //
         if (fProtocol == HTTP) {
-            ThrowXML
+            ThrowXMLwithMemMgr
                 (
                     MalformedURLException
                     , XMLExcepts::URL_ExpectingTwoSlashes
+                    , fMemoryManager
                 );
         }
     }
@@ -1104,8 +1141,8 @@ void XMLURL::parse(const XMLCh* const urlText)
 
             // Try to convert it to a numeric port value and store it
             ptr1++;
-            if (!XMLString::textToBin(ptr1, fPortNum))
-                ThrowXML(MalformedURLException, XMLExcepts::URL_BadPortField);
+            if (!XMLString::textToBin(ptr1, fPortNum, fMemoryManager))
+                ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_BadPortField, fMemoryManager);
         }
 
         // If the host ended up empty, then toss is
@@ -1141,7 +1178,7 @@ void XMLURL::parse(const XMLCh* const urlText)
         fMemoryManager->deallocate(fPath);//delete [] fPath;
         fPath = (XMLCh*) fMemoryManager->allocate
         (
-            (ptr1 - srcPtr + 1) * sizeof(XMLCh)
+            ((ptr1 - srcPtr) + 1) * sizeof(XMLCh)
         );//new XMLCh[(ptr1 - srcPtr) + 1];
         ptr2 = fPath;
         while (srcPtr < ptr1)
@@ -1177,7 +1214,7 @@ void XMLURL::parse(const XMLCh* const urlText)
     {
         fQuery = (XMLCh*) fMemoryManager->allocate
         (
-            (ptr1 - srcPtr + 1) * sizeof(XMLCh)
+            ((ptr1 - srcPtr) + 1) * sizeof(XMLCh)
         );//new XMLCh[(ptr1 - srcPtr) + 1];
         ptr2 = fQuery;
         while (srcPtr < ptr1)
@@ -1303,7 +1340,7 @@ bool XMLURL::parse(const XMLCh* const urlText, XMLURL& xmlURL)
                 {
                     xmlURL.fHost = (XMLCh*) xmlURL.fMemoryManager->allocate
                     (
-                        (ptr1 - srcPtr + 1) * sizeof(XMLCh)
+                        ((ptr1 - srcPtr) + 1) * sizeof(XMLCh)
                     );//new XMLCh[(ptr1 - srcPtr) + 1];
                     ptr2 = xmlURL.fHost;
                     while (srcPtr < ptr1)
@@ -1378,7 +1415,7 @@ bool XMLURL::parse(const XMLCh* const urlText, XMLURL& xmlURL)
 
             // Try to convert it to a numeric port value and store it
             ptr1++;
-            if (!XMLString::textToBin(ptr1, xmlURL.fPortNum))
+            if (!XMLString::textToBin(ptr1, xmlURL.fPortNum, xmlURL.fMemoryManager))
                 return false;
         }
 
@@ -1413,7 +1450,7 @@ bool XMLURL::parse(const XMLCh* const urlText, XMLURL& xmlURL)
     {
         xmlURL.fPath = (XMLCh*) xmlURL.fMemoryManager->allocate
         (
-            (ptr1 - srcPtr + 1) * sizeof(XMLCh)
+            ((ptr1 - srcPtr) + 1) * sizeof(XMLCh)
         );//new XMLCh[(ptr1 - srcPtr) + 1];
         ptr2 = xmlURL.fPath;
         while (srcPtr < ptr1)
@@ -1447,7 +1484,7 @@ bool XMLURL::parse(const XMLCh* const urlText, XMLURL& xmlURL)
     {
         xmlURL.fQuery = (XMLCh*) xmlURL.fMemoryManager->allocate
         (
-            (ptr1 - srcPtr + 1) * sizeof(XMLCh)
+            ((ptr1 - srcPtr) + 1) * sizeof(XMLCh)
         );//new XMLCh[(ptr1 - srcPtr) + 1];
         ptr2 = xmlURL.fQuery;
         while (srcPtr < ptr1)
